chat

package
v0.0.0-...-e6b553b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 6, 2018 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ChatServiceServer

type ChatServiceServer struct {
	// contains filtered or unexported fields
}

ChatServedisiceServer implements the protobuf interface

func Register

func Register(r *r.Redis) *ChatServiceServer

Register binds the redis client to ChatServiceServer

func (*ChatServiceServer) Connect

Connect adds a user into the redis service

func (*ChatServiceServer) ConsoleChat

func (c *ChatServiceServer) ConsoleChat(ctx context.Context, msg *pb.Message) (*google_protobuf.Empty, error)

ConsoleChat sends the messages and makes sure all subscribers receive it

func (*ChatServiceServer) Disconnect

Disconnect removes a user from the set of keys in redis

func (*ChatServiceServer) ListUsers

ListUsers lists all the current users in the room

Jump to