Documentation
¶
Index ¶
- type ChatServiceServer
- func (c *ChatServiceServer) Connect(ctx context.Context, req *pb.ConnectRequest) (*google_protobuf.Empty, error)
- func (c *ChatServiceServer) ConsoleChat(ctx context.Context, msg *pb.Message) (*google_protobuf.Empty, error)
- func (c *ChatServiceServer) Disconnect(ctx context.Context, req *pb.DisconnectRequest) (*google_protobuf.Empty, error)
- func (c *ChatServiceServer) ListUsers(ctx context.Context, e *google_protobuf.Empty) (*pb.UserList, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ChatServiceServer ¶
type ChatServiceServer struct {
// contains filtered or unexported fields
}
ChatServedisiceServer implements the protobuf interface
func Register ¶
func Register(r *r.Redis) *ChatServiceServer
Register binds the redis client to ChatServiceServer
func (*ChatServiceServer) Connect ¶
func (c *ChatServiceServer) Connect(ctx context.Context, req *pb.ConnectRequest) (*google_protobuf.Empty, error)
Connect adds a user into the redis service
func (*ChatServiceServer) ConsoleChat ¶
func (c *ChatServiceServer) ConsoleChat(ctx context.Context, msg *pb.Message) (*google_protobuf.Empty, error)
ConsoleChat sends the messages and makes sure all subscribers receive it
func (*ChatServiceServer) Disconnect ¶
func (c *ChatServiceServer) Disconnect(ctx context.Context, req *pb.DisconnectRequest) (*google_protobuf.Empty, error)
Disconnect removes a user from the set of keys in redis
func (*ChatServiceServer) ListUsers ¶
func (c *ChatServiceServer) ListUsers(ctx context.Context, e *google_protobuf.Empty) (*pb.UserList, error)
ListUsers lists all the current users in the room
Click to show internal directories.
Click to hide internal directories.